@@ -28,6 +28,7 @@ class TransferBroker():
         self._sense_vlan = ''
         self._sense_uuid_2 = ''
         self._sense_vlan_2 = ''
+        self._auth_token = ''
 
     def get_list_src_rcsites(self):
         """Function to get list_src_rcsites attribute."""
@@ -180,3 +181,11 @@ class TransferBroker():
     def set_sense_vlan_2(self, vlan):
         """Function to set sense_vlan_2 attribute."""
         self._sense_vlan_2 = vlan
+
+    def get_auth_token(self):
+        """Function to get auth_token attribute."""
+        return self._auth_token
+
+    def set_auth_token(self, auth):
+        """Function to set auth_token attribute."""
+        self._auth_token = auth
